==> dvc-0.88.0-py37hc8dfbb8_0.tar.bz2: Lib/site-packages/dvc/command/ls/__init__.py <==
import argparse
import logging
import sys

from dvc.command.base import append_doc_link
from dvc.command.base import CmdBaseNoRepo
from dvc.command.ls.ls_colors import LsColors
from dvc.exceptions import DvcException


logger = logging.getLogger(__name__)


def _prettify(entries, with_color=False):
    if with_color:
        ls_colors = LsColors()
        fmt = ls_colors.format
    else:

        def fmt(entry):
            return entry["path"]

    return [fmt(entry) for entry in entries]


class CmdList(CmdBaseNoRepo):
    def run(self):
        from dvc.repo import Repo

        try:
            entries = Repo.ls(
                self.args.url,
                self.args.target,
                rev=self.args.rev,
                recursive=self.args.recursive,
                outs_only=self.args.outs_only,
            )
            if entries:
                entries = _prettify(entries, sys.stdout.isatty())
                logger.info("\n".join(entries))
            return 0
        except DvcException:
            logger.exception("failed to list '{}'".format(self.args.url))
            return 1


def add_parser(subparsers, parent_parser):
    LIST_HELP = "List files and DVC outputs in the repo."
    list_parser = subparsers.add_parser(
        "list",
        parents=[parent_parser],
        description=append_doc_link(LIST_HELP, "list"),
        help=LIST_HELP,
        formatter_class=argparse.RawTextHelpFormatter,
    )
    list_parser.add_argument(
        "url",
        help="Supported urls:\n"
        "/path/to/file\n"
        "/path/to/directory\n"
        "C:\\\\path\\to\\file\n"
        "C:\\\\path\\to\\directory\n"
        "https://github.com/path/to/repo\n"
        "git@github.com:path/to/repo.git\n",
    )
    list_parser.add_argument(
        "-R",
        "--recursive",
        action="store_true",
        help="Recursively list files.",
    )
    list_parser.add_argument(
        "--outs-only", action="store_true", help="Show only DVC outputs."
    )
    list_parser.add_argument(
        "--rev", nargs="?", help="Git revision (e.g. branch, tag, SHA)"
    )
    list_parser.add_argument(
        "target",
        nargs="?",
        help="Path to directory within the repository to list outputs for",
    )
    list_parser.set_defaults(func=CmdList)

==> dvc-0.93.0-py37hc8dfbb8_0.tar.bz2: Lib/site-packages/dvc/command/ls/__init__.py <==
import argparse
import logging
import sys

from dvc.command.base import append_doc_link
from dvc.command.base import CmdBaseNoRepo
from dvc.command.ls.ls_colors import LsColors
from dvc.exceptions import DvcException


logger = logging.getLogger(__name__)


def _prettify(entries, with_color=False):
    if with_color:
        ls_colors = LsColors()
        fmt = ls_colors.format
    else:

        def fmt(entry):
            return entry["path"]

    return [fmt(entry) for entry in entries]


class CmdList(CmdBaseNoRepo):
    def run(self):
        from dvc.repo import Repo

        try:
            entries = Repo.ls(
                self.args.url,
                self.args.path,
                rev=self.args.rev,
                recursive=self.args.recursive,
                outs_only=self.args.outs_only,
            )
            if entries:
                entries = _prettify(entries, sys.stdout.isatty())
                logger.info("\n".join(entries))
            return 0
        except DvcException:
            logger.exception("failed to list '{}'".format(self.args.url))
            return 1


def add_parser(subparsers, parent_parser):
    LIST_HELP = (
        "List repository contents, including files"
        " and directories tracked by DVC and by Git."
    )
    list_parser = subparsers.add_parser(
        "list",
        parents=[parent_parser],
        description=append_doc_link(LIST_HELP, "list"),
        help=LIST_HELP,
        formatter_class=argparse.RawTextHelpFormatter,
    )
    list_parser.add_argument("url", help="Location of DVC repository to list")
    list_parser.add_argument(
        "-R",
        "--recursive",
        action="store_true",
        help="Recursively list files.",
    )
    list_parser.add_argument(
        "--outs-only", action="store_true", help="Show only DVC outputs."
    )
    list_parser.add_argument(
        "--rev", nargs="?", help="Git revision (e.g. branch, tag, SHA)"
    )
    list_parser.add_argument(
        "path",
        nargs="?",
        help="Path to directory within the repository to list outputs for",
    )
    list_parser.set_defaults(func=CmdList)
